
======
Models
======


Transaction Cost Models
-----------------------

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.tcmodel.almgren
    prismstudio.tcmodel.bidaskspread


Risk Models
-----------

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.riskmodel.qis
